@@ -9,7 +9,7 @@
 ##       - utility functions
 ########################################################################
 
-if (dev.cur() <= 1) get(getOption("device"))()
+# if (dev.cur() <= 1) get(getOption("device"))()
 
 opar <- par(ask = interactive() &&
             (.Device %in% c("X11", "GTK", "gnome", "windows","quartz")))
